@@ -7,8 +7,10 @@ import sys
 import time
 
 import pandas as pd
+import numpy as np
 from matplotlib import pyplot as plt
 from termcolor import colored
+from study_lyte.io import write_csv
 
 import radicl
 from radicl import api, probe, serial
@@ -237,7 +239,22 @@ class RADICL(object):
 
             try:
                 data = fn()
+                sr_ts = self.probe.getSetting(setting_name='samplingrate')
                 data = self.dataframe_this(data, data_request)
+                n_samples = data.index.size
+                # Default to using the sensor data sample rate
+                sr = sr_ts
+                # Decimation ratio for periphal sensors
+                ratio = sr_ts / 16000
+
+                if 'acceleration' in data_request:
+                    sr = int(100 * ratio)
+                elif data_request in ['filtereddepth', 'rawdepth', 'rawpressure']:
+                    sr = int(75 * ratio)
+
+                time = np.linspace(0, n_samples / sr, n_samples)
+                data['time'] = time
+                data.set_index('time', inplace=True)
                 success = True
 
             except Exception as e:
@@ -286,7 +303,11 @@ class RADICL(object):
         # Take Measurements
         elif self.state == 3:
             self.take_a_reading()
+
             self.data = self.grab_data(self.daq)
+            # acc_cols = [c for c in self.data.columns if 'Axis' in c]
+            # self.data[acc_cols] = self.data[acc_cols].mul(2)
+
             self.state = 4
 
             if self.data is None:
@@ -298,7 +319,7 @@ class RADICL(object):
 
         # Data output and options
         elif self.state == 4:
-            if self.output_preference == 'write' or self.output_preference == 'both':
+            if self.output_preference in ['write', 'both']:
                 valid = False
 
                 #  Wait for real path
@@ -306,7 +327,7 @@ class RADICL(object):
                     fname = self.get_default_filename()
                     out.msg("Enter in a filepath for the data to be saved:")
                     filename = input("\nPress enter to use default:"
-                                     "\n(Default: ./{0}.csv)".format(fname))
+                                     "\n(Default: {0})".format(fname))
 
                     # Assign a default path
                     if filename == '':
@@ -328,16 +349,10 @@ class RADICL(object):
                                 self.filename))
 
                         if not self.data.empty:
-                            # Write the header so we knwo things about this
-                            with open(self.filename, 'w') as fp:
-                                final = self.probe.getProbeHeader()
-                                fp.writelines(final)
-                                fp.close()
-                            # Write data
-                            self.data.to_csv(self.filename, mode='a')
+                            self.write_probe_data(self.data, filename=filename)
                             self.state = 5
 
-            if self.output_preference in ['plot', 'both'] and self.state == 4:
+            if self.output_preference in ['plot', 'both']:
                 self.data.plot()
                 plt.show()
                 self.state = 5
@@ -516,12 +531,13 @@ class RADICL(object):
 
         return filename
 
-    def write_probe_data(self, df, filename=''):
+    def write_probe_data(self, df, filename='', extra_meta={}):
         """
         Writes out a dataframe with a probe header to csv
         Args:
             df: pandas dataframe containing data
             filename: valid path to output to, if empty uses datetime
+            extra_meta: Dictionary of extra notes to add to the file header
         """
 
         # Recieve a default request
@@ -535,12 +551,9 @@ class RADICL(object):
 
         if not df.empty:
             # Write the header so we know things about this
-            with open(filename, 'w') as fp:
-                final = self.probe.getProbeHeader()
-                fp.writelines(final)
-                fp.close()
-            # Write data
-            df.to_csv(filename, mode='a')
+            meta = self.probe.getProbeHeader()
+            meta.update(extra_meta)
+            write_csv(df, meta, filename)
 
     def ask_user(self, question_str, answer_lst=None, helpme=None,
                  next_state=True, default_answer=None):
